@@ -70,7 +70,7 @@ namespace Banter
 		// Sidebar Pane
 		//
 		private Widget sidebar;
-		private Image avatarImage;
+		private AvatarSelector avatarSelector;
 		private Label myDisplayName;
 		private StatusEntry statusEntry;
 		
@@ -424,13 +424,14 @@ namespace Banter
 		{
 			HBox hbox = new HBox (false, 4);
 			
+			avatarSelector = new AvatarSelector();
+			
 			if( (PersonManager.Me != null) && (PersonManager.Me.Photo != null) )
-				avatarImage = new Image(PersonManager.Me.Photo.ScaleSimple(48,48,Gdk.InterpType.Bilinear));
-			else
-				avatarImage = new Image (Utilities.GetIcon ("blank-photo-128", 32));
+				avatarSelector.Pixbuf = PersonManager.Me.Photo;
 
-			avatarImage.Show ();
-			hbox.PackStart (avatarImage, false, false, 0);
+			avatarSelector.Show();
+
+			hbox.PackStart (avatarSelector, false, false, 0);
 			
 			VBox vbox = new VBox (false, 0);
 			vbox.Show ();
@@ -461,8 +462,7 @@ namespace Banter
 		
 		private void OnStatusEntryChanged (Presence presence)
 		{
-			Logger.Debug ("Setting precense on Me to {0}", presence.Message);
-			
+			Logger.Debug ("Setting presence on Me to {0}", presence.Message);
 			if (PersonManager.Me != null) {
 				PersonManager.Me.SetStatus (presence);
 				
@@ -841,8 +841,9 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 					Gtk.ButtonsType.OkCancel,
 					Catalog.GetString ("New group window"),
 					Catalog.GetString ("Enter the name of the new group you'd like to create."));
-			
+
 			Gtk.Entry groupNameEntry = new Entry ();
+            groupNameEntry.ActivatesDefault = true;
 			dialog.ExtraWidget = groupNameEntry;
 			
 			int returnCode = dialog.Run ();
@@ -925,7 +926,9 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 		
 		private void OnMyPresenceUpdated (Person me)
 		{
+			statusEntry.PresenceChanged -= OnStatusEntryChanged;
 			statusEntry.Presence = me.Presence;
+			statusEntry.PresenceChanged += OnStatusEntryChanged;
 		}
 		
 		private void OnGroupRowInserted (object sender, RowInsertedArgs args)
@@ -1033,7 +1036,7 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 		private void OnConfigureEvent (object sender, ConfigureEventArgs args)
 		{
 			QueueSaveState ();
-		}
+		}		
 		#endregion
 	}
 
